package eu.pozimski.alarmclockconfigurator.ui.elements

import androidx.compose.material.AlertDialog
import androidx.compose.material.Button
import androidx.compose.material.Text
import androidx.compose.runtime.Composable

@Composable
fun DeleteAlertDialog(
    onDismissRequest: () -> Unit, onConfirm: () -> Unit,
    deletionElementNameCreator: () -> String
) {
    ConfirmationDialog(
        onDismissRequest = onDismissRequest,
        onConfirm = onConfirm,
        request = "Do you really want to delete the current wakeup time for "
                + deletionElementNameCreator.invoke() + "?"
    )
}

@Composable
fun ConfirmationDialog(
    onDismissRequest: () -> Unit, onConfirm: () -> Unit,
    request: String
) {
    AlertDialog(
        onDismissRequest = onDismissRequest,
        dismissButton = {
            Button(onClick = onDismissRequest, content = { Text(text = "Cancel") })
        },
        confirmButton = {
            Button(
                onClick = onConfirm,
                content = { Text(text = "OK") })
        },
        text = {
            Text(
                text = request
            )
        })
}

@Composable
fun DisableAlertDialog(
    onDismissRequest: () -> Unit, onConfirm: () -> Unit,
    elementNameCreator: () -> String
) {
    ConfirmationDialog(
        onDismissRequest = onDismissRequest,
        onConfirm = onConfirm,
        request = "Do you really want to disable the alarm for "
                + elementNameCreator.invoke() + "?"
    )
}

@Composable
fun ErrorDialog(onDismissRequest: () -> Unit, currentError: String?) {
    AlertDialog(
        onDismissRequest = onDismissRequest,
        text = {
            Text(text = "An error occurred while accessing data:\n\n%s".format(currentError))
        },
        confirmButton = {
            Button(
                onClick = onDismissRequest,
                content = { Text(text = "OK") })
        }
    )
}